==> huaweicloudsdkief-3.1.52-py2.py3-none-any.whl: huaweicloudsdkief/v1/model/update_app_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateAppBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'app': 'AppUpdate'
    }

    attribute_map = {
        'app': 'app'
    }

    def __init__(self, app=None):
        """UpdateAppBody

        The model defined in huaweicloud sdk

        :param app: 
        :type app: :class:`huaweicloudsdkief.v1.AppUpdate`
        """
        
        

        self._app = None
        self.discriminator = None

        self.app = app

    @property
    def app(self):
        """Gets the app of this UpdateAppBody.

        :return: The app of this UpdateAppBody.
        :rtype: :class:`huaweicloudsdkief.v1.AppUpdate`
        """
        return self._app

    @app.setter
    def app(self, app):
        """Sets the app of this UpdateAppBody.

        :param app: The app of this UpdateAppBody.
        :type app: :class:`huaweicloudsdkief.v1.AppUpdate`
        """
        self._app = app

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAppBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkief-3.1.146-py2.py3-none-any.whl: huaweicloudsdkief/v1/model/update_app_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateAppBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'app': 'AppUpdate'
    }

    attribute_map = {
        'app': 'app'
    }

    def __init__(self, app=None):
        r"""UpdateAppBody

        The model defined in huaweicloud sdk

        :param app: 
        :type app: :class:`huaweicloudsdkief.v1.AppUpdate`
        """
        
        

        self._app = None
        self.discriminator = None

        self.app = app

    @property
    def app(self):
        r"""Gets the app of this UpdateAppBody.

        :return: The app of this UpdateAppBody.
        :rtype: :class:`huaweicloudsdkief.v1.AppUpdate`
        """
        return self._app

    @app.setter
    def app(self, app):
        r"""Sets the app of this UpdateAppBody.

        :param app: The app of this UpdateAppBody.
        :type app: :class:`huaweicloudsdkief.v1.AppUpdate`
        """
        self._app = app

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAppBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
